@@ -24,7 +24,7 @@
 #ifndef MAIN_H
 #define MAIN_H
 
-#include "startup_i18n.h"
+#include "ui/startup_i18n.h"
 #include <stdio.h>
 #include <string.h>
 #include <libosso.h>
@@ -36,6 +36,4 @@
 #include "appdata.h"
 #include "settings.h"
 
-
-
 #endif
