@@ -72,19 +72,4 @@ gboolean set_game_state(const guint state, osso_rpc_t *retval);
  */
 gboolean set_game_state_async(const guint state);
 
-/**
- Initialize communication
-
- @returns TRUE on success, FALSE otherwise
- */
-gboolean init_communication(void);
-
-/**
- Close application if user presses long ESC Key from game.
- 
- @param reset_key Reset Esc timeout key to FALSE
- @return TRUE if user presses long-ESC key from game.
- */
-gboolean check_escape_timeout(gboolean reset_key);
-
 #endif
