@@ -27,10 +27,11 @@
 #include <libgen.h>
 #include <hildon/hildon-note.h>
 #include <hildon/hildon-helper.h>
-#include <libgnomevfs/gnome-vfs.h>
 #include <hildon/hildon-help.h>
 #include "interface.h"
 #include "dbus.h"
+#include "startup_plugin.h"
+#include "../state_save.h"
 
 #define PLUGIN_HEIGHT           100
 #define PLUGIN_WIDTH             -1
@@ -47,7 +48,7 @@ show_picture(gpointer user_data)
 {
     AppUIData *app_ui_data = (AppUIData *) user_data;
     gtk_image_set_from_file(GTK_IMAGE(app_ui_data->game_image),
-                            startup_config_read_entry(startup_app_get_config (app_ui_data), "Image", NULL));
+                            startup_config_read_entry(startup_app_get_config (app_data->startup_app), "Image", NULL));
     return FALSE;
 }
 
@@ -93,7 +94,6 @@ ui_create_indt_menu(AppUIData * ui)
     ui->game_game_menu = game_menu;
     
     /* Create the menu items */
-    // FIX ME:create generic ids 
     play_item =
         gtk_menu_item_new_with_label(_("game_me_chess_menu_game_play"));
     gtk_menu_append(GTK_MENU(game_menu), play_item);
@@ -107,9 +107,9 @@ ui_create_indt_menu(AppUIData * ui)
     g_signal_connect(G_OBJECT(ui->game_restart_menu), "activate",
                      G_CALLBACK(startup_ui_game_restart_cb), (gpointer) ui);
 
-    if (ui->plugin && ui->plugin->info->load_menu)
+    if (app_data->plugin && app_data->plugin->info->load_menu)
     {
-        if (ui->plugin->menu_open_save && ui->plugin->info->plugin_cb)
+        if (app_data->plugin->menu_open_save && app_data->plugin->info->plugin_cb)
         {
             gtk_menu_append(GTK_MENU(game_menu), gtk_menu_item_new());
             open_item =
@@ -118,22 +118,28 @@ ui_create_indt_menu(AppUIData * ui)
             ui->open_item = open_item;
             gtk_menu_append(GTK_MENU(game_menu), open_item);
             g_signal_connect(G_OBJECT(open_item), "activate",
-                             G_CALLBACK(ui->plugin->info->plugin_cb),
+                             G_CALLBACK(app_data->plugin->info->plugin_cb),
                              (gpointer) ME_GAME_OPEN);
             ui->game_save_menu =
                 gtk_menu_item_new_with_label(_
                                              ("game_me_chess_menu_game_save"));
             gtk_menu_append(GTK_MENU(game_menu), ui->game_save_menu);
             g_signal_connect(G_OBJECT(ui->game_save_menu), "activate",
-                             G_CALLBACK(ui->plugin->info->plugin_cb),
+                             G_CALLBACK(app_data->plugin->info->plugin_cb),
                              (gpointer) ME_GAME_SAVE);
 
+            /* Save reference of save menu item to plugin so it can handle
+             * sensitivity state if/when savefile is changed to readonly */
+            app_data->plugin->info->plugin_cb(GTK_WIDGET(ui->game_save_menu), (gpointer) MA_GAME_SAVEMENU_REFERENCE);
+
+
             ui->game_saveas_menu =
                 gtk_menu_item_new_with_label(_
                                              ("game_me_chess_menu_game_save_as"));
             gtk_menu_append(GTK_MENU(game_menu), ui->game_saveas_menu);
+
             g_signal_connect(G_OBJECT(ui->game_saveas_menu), "activate",
-                             G_CALLBACK(ui->plugin->info->plugin_cb),
+                             G_CALLBACK(app_data->plugin->info->plugin_cb),
                              (gpointer) ME_GAME_SAVE_AS);
 
 
@@ -146,7 +152,7 @@ ui_create_indt_menu(AppUIData * ui)
             }
         }
 
-        plugin_menu = ui->plugin->info->load_menu(&nmenu_items);
+        plugin_menu = app_data->plugin->info->load_menu(&nmenu_items);
         // Conditional creation, by game type.
         for (i = 0; i < nmenu_items; i++)
         {
@@ -155,8 +161,8 @@ ui_create_indt_menu(AppUIData * ui)
                 gtk_menu_append(GTK_MENU(main_menu_bar), plugin_menu[i]);
             }
         }
-        if (ui->plugin->info->update_menu)
-            ui->plugin->info->update_menu();
+        if (app_data->plugin->info->update_menu)
+            app_data->plugin->info->update_menu();
     }
     close_item = gtk_menu_item_new_with_label(_("game_me_main_menu_close"));
     
@@ -188,7 +194,7 @@ ui_create_indt_menu(AppUIData * ui)
 
 /* Create the main window */
 void
-ui_create_main_window(AppData * app_data)
+ui_create_main_window()
 {
     AppUIData *app_ui_data;
 
@@ -196,43 +202,27 @@ ui_create_main_window(AppData * app_data)
 
     app_ui_data = app_data->app_ui_data;
 
-    /* Initialize app ui data pointer in callbacks module */
-    cb_init(app_ui_data);
 
     app_ui_data->app = ui_create_main_app(app_data);
     g_assert(app_ui_data->app);
    
-    /* Removed code to create ui depending of get_game_type() function call
-     * since game_type is no hardcoded to allways be gt_indt 
-     * */
-
     ui_create_indt_view(app_ui_data);
-    if (app_ui_data->plugin->menu_open_save && app_ui_data->plugin->info->plugin_cb)
-    {
-        osso_log(LOG_DEBUG, "Creating two part title");
-    }
 
     g_assert(app_ui_data->main_view);
 
     /* Connect delete signal */
 	
-	/* Ignore this, and use on_delete_event only
-    g_signal_connect(G_OBJECT(app_ui_data->main_view), "delete_event",
-                     G_CALLBACK(game_quit_cb), (gpointer) app_ui_data); */
-
-
     g_signal_connect(G_OBJECT(app_ui_data->app), "notify::is-topmost",
                      G_CALLBACK(top_changed), (gpointer) app_data);
 
     hildon_program_add_window(app_ui_data->app, app_ui_data->main_view);
 
-
     ui_create_indt_menu(app_ui_data);
 
     gtk_widget_show_all(GTK_WIDGET(app_ui_data->main_view));
 
-    app_ui_data->skip_box_update = FALSE;
-    app_ui_data->chess_saved = FALSE;
+    /* read state */
+    read_state();
 
     ui_update_status(app_ui_data);
 }
@@ -245,7 +235,6 @@ ui_create_main_app(AppData * app_data)
     /* Create HildonApp */
     result = HILDON_PROGRAM(hildon_program_get_instance());
 
-
     hildon_program_set_can_hibernate(result, FALSE);
 
     return result;
@@ -259,16 +248,9 @@ ui_update_status(AppUIData * app_ui_data)
     /* Get game state */
     GameState gs = get_game_state();
 
-    if (app_ui_data->play_button == NULL)
-        return FALSE;
-    if (app_ui_data->continue_button == NULL)
-        return FALSE;
-    if (app_ui_data->controls_state_label == NULL)
-        return FALSE;
-
-    g_assert(app_ui_data->play_button);
-    g_assert(app_ui_data->continue_button);
-    g_assert(app_ui_data->controls_state_label);
+    g_return_val_if_fail(app_ui_data->play_button
+		    && app_ui_data->continue_button 
+		    && app_ui_data->controls_state_label, FALSE);
 
     /* Game is unloaded */
     if (gs == gs_unloaded)
@@ -336,7 +318,6 @@ ui_create_games_common_view(AppUIData * app_ui_data)
     /* Get game state */
     GameState gs = get_game_state();
 
-
     /* Create a vbox for all our stuff inside main view */
     app_ui_data->main_vbox = gtk_vbox_new(FALSE, 0);
     g_assert(app_ui_data->main_vbox);
@@ -433,8 +414,6 @@ ui_create_games_common_view(AppUIData * app_ui_data)
     gtk_fixed_put(GTK_FIXED(app_ui_data->controls_fixed),
                   app_ui_data->play_button, FIRST_BUTTON_LEFT, BUTTONS_TOP);
 
-
-
     /* Show proper buttons */
     if (gs == gs_unloaded || gs == gs_closed)
     {
@@ -472,8 +451,6 @@ ui_create_games_common_view(AppUIData * app_ui_data)
     {
         gtk_widget_set_sensitive(app_ui_data->restart_button, TRUE);
     }
-
-
 }
 
 
@@ -485,18 +462,19 @@ ui_create_indt_view(AppUIData * app_ui_data)
     const gchar *game_gettext_package;
     const gchar *msgid;
     GtkWidget *game_widget = NULL;
+    
     result = HILDON_WINDOW(hildon_window_new());
     game_gettext_package =
-        startup_config_read_entry(startup_app_get_config(app_ui_data),
+        startup_config_read_entry(startup_app_get_config(app_data->startup_app),
                                   "GettextPackage", NULL);
-    if (app_ui_data->plugin && game_gettext_package)
-        app_ui_data->plugin->gettext_package = game_gettext_package;
+    if (app_data->plugin && game_gettext_package)
+        app_data->plugin->gettext_package = game_gettext_package;
 
     game_gettext_package =
-        startup_config_read_entry(startup_app_get_config(app_ui_data),
+        startup_config_read_entry(startup_app_get_config(app_data->startup_app),
                                   "GettextPackage", NULL);
     msgid =
-        startup_config_read_entry(startup_app_get_config(app_ui_data),
+        startup_config_read_entry(startup_app_get_config(app_data->startup_app),
                                   "TitleId", NULL);
 
     if (game_gettext_package && msgid)
@@ -508,7 +486,7 @@ ui_create_indt_view(AppUIData * app_ui_data)
     {
         app_ui_data->game_title =
             (gchar *)
-            startup_config_read_entry(startup_app_get_config(app_ui_data),
+            startup_config_read_entry(startup_app_get_config(app_data->startup_app),
                                       "Title", NULL);
     }
     g_assert(app_ui_data->game_title);
@@ -525,7 +503,6 @@ ui_create_indt_view(AppUIData * app_ui_data)
                      (gpointer) (app_ui_data));
     g_assert(result);
     app_ui_data->main_view = result;
-    // gtk_widget_show_all(GTK_WIDGET(app_ui_data->mainview));
 
     g_signal_connect(G_OBJECT(app_ui_data->main_view), "destroy",
                      G_CALLBACK(game_quit_cb), (gpointer) app_ui_data);
@@ -540,8 +517,8 @@ ui_create_indt_view(AppUIData * app_ui_data)
     gtk_container_add(GTK_CONTAINER(app_ui_data->main_vbox),
                       app_ui_data->game_hbox);
 
-    if (app_ui_data->plugin)
-        game_widget = app_ui_data->plugin->info->load();
+    if (app_data->plugin)
+        game_widget = app_data->plugin->info->load();
     else
         game_widget = gtk_vbox_new(FALSE, 0);
     g_assert(game_widget);
@@ -549,7 +526,6 @@ ui_create_indt_view(AppUIData * app_ui_data)
     gtk_widget_set_size_request(game_widget, PLUGIN_WIDTH, PLUGIN_HEIGHT);
     gtk_container_add(GTK_CONTAINER(app_ui_data->main_vbox), game_widget);
 
-
     hildon_program_add_window(app_ui_data->app, app_ui_data->main_view);
 
     gtk_widget_show_all(GTK_WIDGET(app_ui_data->main_view));
@@ -593,7 +569,7 @@ ui_set_dimmed_menu_item_callback(AppUIData * app_ui_data)
                                               (app_ui_data->
                                                game_restart_menu),
                                               _("game_ib_not_available"));
-    if (app_ui_data->plugin->menu_open_save)
+    if (app_data->plugin->menu_open_save)
     {
 
         hildon_helper_set_insensitive_message(GTK_WIDGET
@@ -605,9 +581,7 @@ ui_set_dimmed_menu_item_callback(AppUIData * app_ui_data)
                                               (app_ui_data->
                                                game_saveas_menu),
                                               _("game_ib_not_available"));
-
     }
-    
 }
 
 
@@ -627,9 +601,7 @@ ui_show_save_nomem_dialog(AppUIData * app_ui_data)
     g_signal_connect(G_OBJECT(note), "response",
                      G_CALLBACK(save_nomem_response), app_ui_data);
     app_ui_data->nomem_dialog = GTK_WIDGET(note);
-    // gtk_dialog_run(GTK_DIALOG(note));
     gtk_widget_show_all(GTK_WIDGET(note));
-    // gtk_widget_destroy(GTK_WIDGET(note));
 
     gtk_window_set_title(GTK_WINDOW(app_ui_data->main_view), "");
     settings_set_string(SETTINGS_CHESS_SAVE_FILE, "");
